@@ -5,6 +5,8 @@ functions used throughout TiddlyWeb and plugins.
 Web specific utilities are in :py:mod:`tiddlyweb.web.util`.
 """
 
+from __future__ import print_function
+
 import logging
 import codecs
 import os
@@ -69,8 +71,9 @@ def read_config(global_config):
     try:
         from tiddlywebconfig import config as custom_config
         merge_config(global_config, custom_config, reconfig=False)
-    except ImportError, exc:
-        if not exc.args[0].endswith('tiddlywebconfig'):
+    except ImportError as exc:
+        if not ('module named' in exc.args[0]
+                and 'tiddlywebconfig' in exc.args[0]):
             raise  # error within tiddlywebconfig.py
 
 
@@ -78,7 +81,7 @@ def sha(data=''):
     """
     Create a sha1 digest of the ``data``.
     """
-    return sha1(data)
+    return sha1(data.encode('UTF-8'))
 
 
 def binary_tiddler(tiddler):
@@ -121,9 +124,8 @@ def read_utf8_file(filename):
 
     Allow any exceptions to raise.
     """
-    source_file = codecs.open(filename, encoding='utf-8')
-    content = source_file.read()
-    source_file.close()
+    with codecs.open(filename, encoding='utf-8') as source_file:
+        content = source_file.read()
     return content
 
 
@@ -146,19 +148,8 @@ def renderable(tiddler, environ=None):
 def std_error_message(message):
     """
     Display ``message`` on the ``stderr`` console.
-
-    Some finagling is done to ensure that unicode content makes its
-    way to the console even if there are encoding problems.
     """
-    try:
-        print >> sys.stderr, message.encode('utf-8', 'replace')
-    # there's a mismatch between our encoding and the output terminal
-    except UnicodeDecodeError:
-        try:
-            print >> sys.stderr, message
-        except UnicodeDecodeError:
-            print >> sys.stderr, ('cannot display message due to '
-                    'mismatching terminal character encoding')
+    print(message, file=sys.stderr)
 
 
 def superclass_name(instance):
